*************
Developer API
*************

The classes and functions documented here will be of use to developers who wish
to create their own custom ASDF types and extensions.

.. automodapi:: asdf.types

.. automodapi:: asdf.extension

.. automodapi:: asdf.resource

.. automodapi:: asdf.yamlutil

.. automodapi:: asdf.util

.. automodapi:: asdf.versioning

.. automodapi:: asdf.tests.helpers
